/*
 * Copyright (C) 2021 Associated Universities, Inc. Washington DC, USA.
 *
 * This file is part of NRAO Workspaces.
 *
 * Workspaces is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Workspaces is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Workspaces.  If not, see <https://www.gnu.org/licenses/>.
 */
import { Component, OnInit } from '@angular/core';
import {NgbActiveModal} from "@ng-bootstrap/ng-bootstrap";
import {SelectedFilterService} from "../../services/selected-filter.service";
import {Subscription} from "rxjs";

@Component({
  selector: 'ngdb-modal-content',
  templateUrl: './load-filters.component.html',
  styleUrls: ['./load-filters.component.scss']
})
export class LoadFiltersComponent implements OnInit {

  public savedFilters: any;
  public savedFiltersSub: Subscription;

  constructor(public activeModal: NgbActiveModal, public selectedFilterService: SelectedFilterService) {
    this.savedFiltersSub = this.selectedFilterService.savedFilters$.subscribe((savedFilters) => {
      this.savedFilters = savedFilters;
    });
  }

  ngOnInit() {
  }

  ngOnDestroy(){
    if(this.savedFiltersSub){ this.savedFiltersSub.unsubscribe(); }
  }

  loadFilters(name: string){
    this.selectedFilterService.loadFilters(name);
    this.activeModal.close('Loaded Filters');
  }

  deleteFilters(name: string){
    this.selectedFilterService.deleteSavedFilters(name);
  }

}
