/*
 * Copyright (C) 2021 Associated Universities, Inc. Washington DC, USA.
 *
 * This file is part of NRAO Workspaces.
 *
 * Workspaces is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Workspaces is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Workspaces.  If not, see <https://www.gnu.org/licenses/>.
 */
import { CapabilityVersion } from "../../../../model/capability-version";
import {JsonObject} from "@angular/compiler-cli/ngcc/src/packages/entry_point";
import { Component, Input, OnInit } from '@angular/core';

@Component({
  selector: 'app-metadata',
  templateUrl: './metadata.component.html',
  styleUrls: ['./metadata.component.scss']
})
export class MetadataComponent implements OnInit {

  @Input() capabilityVersion: CapabilityVersion;

  ngOnInit(): void {

  }
  /**
   * Check if JsonObject is empty
   * Taken from: https://stackoverflow.com/questions/679915/how-do-i-test-for-an-empty-javascript-object
   * @param obj  Object to be checked
   * @return boolean  true if object is empty; else false
   */
  isEmpty(obj: JsonObject): boolean {
    for (const prop in obj) {
      if (obj.hasOwnProperty(prop)) {
        return false;
      }
    }

    return true;
  }

  /**
   * Is there a CARTA session for this capability version?
   *
   *  @return boolean  true if carta_url exists in workflow_metadata
   */
  hasCarta(): boolean {

    // return true if workflow_metadata contains carta_url
    if (this.capabilityVersion.workflow_metadata !== null) {
      const metadata = this.capabilityVersion.workflow_metadata
      if (metadata.hasOwnProperty('carta_url') ) {
        if (metadata['carta_url'] != ""){
          return true
        } else {
          return false
        }
      }
    }

    return false;
  }

  copyToClipboard(text: string): void {
    const selBox = document.createElement('textarea');
    selBox.style.position = 'fixed';
    selBox.style.left = '0';
    selBox.style.top = '0';
    selBox.style.opacity = '0';
    selBox.value = text;
    document.body.appendChild(selBox);
    selBox.focus();
    selBox.select();
    document.execCommand('copy');
    document.body.removeChild(selBox);

    // animate copy-to-clipboard
    const copySpan = document.querySelector('.copyEvent:not(.animate)')
    if(copySpan) {
      copySpan.classList.add('animate');
      copySpan.addEventListener('animationend', () => copySpan.classList.remove('animate') );
    }
  }

  getSizeOfMetadata(metadata: JsonObject): number {
    let keys = Object.keys(metadata)
    return keys.length
  }

}
